/**
 * @file test.c
 * This is the main test program start point.
 */

#include <stdio.h>
#include <propeller.h>

#include "gyro_driver.h"


/* Static definitions */
#define SCL 5
#define SDA 3

#define AVG_COUNT 100

/**
 * Main program function.
 */
int main(void)
{
    extern unsigned int _load_start_gyro_drivercog[];

    gyro_init_t gyro;

    int i;
    int x, y, z;
    int offX, offY, offZ;
    int accX = 0;
    int accY = 0;
    int accZ = 0;
    uint32_t t;

    /* set some parameters up in the mailbox structure */
    gyro.scl = SCL;
    gyro.sda = SDA;

    /* launch the program defined in "gyro_driver.cogc" into a new cog */
    cognew(_load_start_gyro_drivercog, &gyro);
    
//    waitcnt(CNT + CLKFREQ);
    
    /* find an offset value by taking an average */
    for(i = 0; i < AVG_COUNT; i++)
    {
        accX += gyro.mailbox->x;
        accY += gyro.mailbox->y;
        accZ += gyro.mailbox->z;

        waitcnt(CNT + CLKFREQ/100);
    }

    offX = accX/AVG_COUNT;
    offY = accY/AVG_COUNT;
    offZ = accZ/AVG_COUNT;


    /* clear the accumulator values for each axis */
    accX = accY = accZ = 0;
    
    t = CNT;
    for(;;)
    {
        /* copy data out of the mailbox structure into local variales */
        x = gyro.mailbox->x;
        y = gyro.mailbox->y;
        z = gyro.mailbox->z;

//        accX = accX + x;
//        accY = accY + y;
//        accZ = accZ + z;

        /* print the data only once per time period (defined by setting "t" to a new value) */
        if(CNT > t)
        {
            putchar(0);           //clear the terminal for to display new data (can be choppy)
            
            printf("RAW x= %d  y= %d  z= %d      \n", x, y, z);
            printf("Acc x= %d  y= %d  z= %d      \n", accX, accY, accZ);
            printf("Off x= %d  y= %d  z= %d      \n", offX, offY, offZ);
            t += CLKFREQ/10;
        }

        //waitcnt(CNT + CLKFREQ/25);
    }

    return 0;
}

